@@ -3,7 +3,7 @@
  ** The Sleuth Kit 
  **
  ** Brian Carrier [carrier <at> sleuthkit [dot] org]
- ** Copyright (c) 2010-2014 Brian Carrier.  All Rights reserved
+ ** Copyright (c) 2010-2018 Brian Carrier.  All Rights reserved
  **
  ** This software is distributed under the Common Public License 1.0
  **
@@ -1312,16 +1312,17 @@ JNIEXPORT jlong JNICALL
 
 
 /*
- * Open an image pointer for the given image
+ * Open an image pointer for the given image.
  * @return the created TSK_IMG_INFO pointer
  * @param env pointer to java environment this was called from
  * @param obj the java object this was called from
  * @param paths the paths to the image parts
  * @param num_imgs number of image parts
+ * @param sector_size the sector size (use '0' for autodetect)
  */
 JNIEXPORT jlong JNICALL
     Java_org_sleuthkit_datamodel_SleuthkitJNI_openImgNat(JNIEnv * env,
-    jclass obj, jobjectArray paths, jint num_imgs) {
+    jclass obj, jobjectArray paths, jint num_imgs, jint sector_size) {
     TSK_IMG_INFO *img_info;
     jboolean isCopy;
 
@@ -1342,7 +1343,7 @@ JNIEXPORT jlong JNICALL
     // open the image
     img_info =
         tsk_img_open_utf8((int) num_imgs, imagepaths8, TSK_IMG_TYPE_DETECT,
-        0);
+        sector_size);
     if (img_info == NULL) {
         setThrowTskCoreError(env, tsk_error_get());
     }
