@@ -1,7 +1,7 @@
 /*
  * Sleuth Kit Data Model
  *
- * Copyright 2011-2017 Basis Technology Corp.
+ * Copyright 2011-2018 Basis Technology Corp.
  * Contact: carrier <at> sleuthkit <dot> org
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -24,6 +24,9 @@ import java.util.Collections;
 import java.util.List;
 import java.util.Objects;
 import java.util.ResourceBundle;
+import java.util.TimeZone;
+import java.util.logging.Level;
+import java.util.logging.Logger;
 
 /**
  * Represents an attribute of an artifact posted to the blackboard. Instances
@@ -42,6 +45,8 @@ import java.util.ResourceBundle;
 public class BlackboardAttribute {
 
 	private static final char[] HEX_ARRAY = "0123456789ABCDEF".toCharArray();
+	private static final Logger LOGGER = Logger.getLogger(BlackboardAttribute.class.getName());
+	
 	private static final ResourceBundle bundle = ResourceBundle.getBundle("org.sleuthkit.datamodel.Bundle");
 	private BlackboardAttribute.Type attributeType;
 	private final int valueInt;
@@ -249,7 +254,7 @@ public class BlackboardAttribute {
 		if (valueString == null) {
 			this.valueString = "";
 		} else {
-			this.valueString = replaceNulls(valueString);
+			this.valueString = replaceNulls(valueString).trim();
 		}
 		this.valueBytes = new byte[0];
 		this.context = "";
@@ -280,7 +285,7 @@ public class BlackboardAttribute {
 		if (valueString == null) {
 			this.valueString = "";
 		} else {
-			this.valueString = replaceNulls(valueString);
+			this.valueString = replaceNulls(valueString).trim();
 		}
 		this.valueBytes = new byte[0];
 		this.context = "";
@@ -518,8 +523,22 @@ public class BlackboardAttribute {
 				return Double.toString(getValueDouble());
 			case BYTE:
 				return bytesToHexString(getValueBytes());
-			case DATETIME:
-				return FsContent.epochToTime(getValueLong());
+				
+			case DATETIME: {
+				try {
+					final Content dataSource = getParentArtifact().getDataSource();
+					if ((dataSource != null) && (dataSource instanceof Image )) {
+						// return the date/time string in the timezone associated with the datasource,
+						Image  image = (Image) dataSource;
+						TimeZone tzone = TimeZone.getTimeZone(image.getTimeZone());
+						return TimeUtilities.epochToTime(getValueLong(), tzone);
+					} 
+				} catch (TskException ex) {
+					LOGGER.log(Level.WARNING, "Could not get timezone for image", ex); //NON-NLS
+					// return time string in default timezone
+					return TimeUtilities.epochToTime(getValueLong());
+				}
+			}
 		}
 		return "";
 	}
@@ -556,7 +575,7 @@ public class BlackboardAttribute {
 		if (valueString == null) {
 			this.valueString = "";
 		} else {
-			this.valueString = replaceNulls(valueString);
+			this.valueString = replaceNulls(valueString).trim();
 		}
 		if (valueBytes == null) {
 			this.valueBytes = new byte[0];
@@ -1272,7 +1291,28 @@ public class BlackboardAttribute {
 				TSK_BLACKBOARD_ATTRIBUTE_VALUE_TYPE.INTEGER),
 		TSK_HEADERS(123, "TSK_HEADERS", //NON-NLS
 				bundle.getString("BlackboardAttribute.tskHeaders.text"),
-				TSK_BLACKBOARD_ATTRIBUTE_VALUE_TYPE.STRING);
+				TSK_BLACKBOARD_ATTRIBUTE_VALUE_TYPE.STRING),
+		TSK_ID(124, "TSK_ID", //NON-NLS
+				bundle.getString("BlackboardAttribute.tskId.text"),
+				TSK_BLACKBOARD_ATTRIBUTE_VALUE_TYPE.STRING),
+		TSK_SSID(125, "TSK_SSID", //NON-NLS
+				bundle.getString("BlackboardAttribute.tskSsid.text"),
+						TSK_BLACKBOARD_ATTRIBUTE_VALUE_TYPE.STRING),
+		TSK_BSSID(126, "TSK_BSSID", //NON-NLS
+				bundle.getString("BlackboardAttribute.tskBssid.text"),
+						TSK_BLACKBOARD_ATTRIBUTE_VALUE_TYPE.STRING),
+		TSK_MAC_ADDRESS(127, "TSK_MAC_ADDRESS", //NON-NLS
+				bundle.getString("BlackboardAttribute.tskMacAddress.text"),
+						TSK_BLACKBOARD_ATTRIBUTE_VALUE_TYPE.STRING),
+		TSK_IMEI(128, "TSK_IMEI", //NON-NLS
+				bundle.getString("BlackboardAttribute.tskImei.text"),
+						TSK_BLACKBOARD_ATTRIBUTE_VALUE_TYPE.STRING),
+		TSK_IMSI(129, "TSK_IMSI", //NON-NLS
+				bundle.getString("BlackboardAttribute.tskImsi.text"),
+						TSK_BLACKBOARD_ATTRIBUTE_VALUE_TYPE.STRING),
+		TSK_ICCID(130, "TSK_ICCID", //NON-NLS
+				bundle.getString("BlackboardAttribute.tskIccid.text"),
+						TSK_BLACKBOARD_ATTRIBUTE_VALUE_TYPE.STRING);
 
 		private final int typeID;
 		private final String typeName;
