@@ -83,7 +83,5 @@ public class EncodedFileOutputStream extends BufferedOutputStream {
 		}
 
 		super.write(encodedData, off, len);
-		//encodedData not gc'd until nulled out.
-		encodedData = null;
 	}
 }
