@@ -107,6 +107,18 @@ public class LocalFilesDataSource extends VirtualDirectory implements DataSource
 	public String getTimeZone() {
 		return timezone;
 	}
+	
+	/**
+	 * Set the name for this data source.
+	 * 
+	 * @param newName       The new name for the data source
+	 * 
+	 * @throws TskCoreException Thrown if an error occurs while updating the database
+	 */
+	@Override
+	public void setDisplayName(String newName) throws TskCoreException {
+		this.getSleuthkitCase().setFileName(newName, objectId);
+	}
 
 	/**
 	 * Gets the size of the contents of the data source in bytes. This size can
