@@ -264,15 +264,18 @@ hfs_dir_open_meta_cb(HFS_INFO * hfs, int8_t level_type,
             info->fs_name->flags = TSK_FS_NAME_FLAG_ALLOC;
 
             // Make sure there is enough space in cur_key for the name 
-            // (name is unicode so each characters is two bytes; 6 bytes of non-name characters)
-            if ((uint32_t)(tsk_getu16(hfs->fs_info.endian, cur_key->name.length)) * 2 > tsk_getu16(hfs->fs_info.endian, cur_key->key_len) - 6) {
+            // (name is unicode so each characters is two bytes; 6 bytes
+            // of non-name characters)
+            const int32_t nameLength =
+                tsk_getu16(hfs->fs_info.endian, cur_key->name.length);
+
+            if (2*nameLength > tsk_getu16(hfs->fs_info.endian, cur_key->key_len) - 6) {
                 error_returned
                 ("hfs_dir_open_meta_cb: name length is too long");
                 return HFS_BTREE_CB_ERR;
             }
             if (hfs_UTF16toUTF8(fs, (uint8_t *) cur_key->name.unicode,
-                    tsk_getu16(hfs->fs_info.endian, cur_key->name.length),
-                    info->fs_name->name, HFS_MAXNAMLEN + 1,
+                    nameLength, info->fs_name->name, HFS_MAXNAMLEN + 1,
                     HFS_U16U8_FLAG_REPLACE_SLASH)) {
                 return HFS_BTREE_CB_ERR;
             }
@@ -322,15 +325,17 @@ hfs_dir_open_meta_cb(HFS_INFO * hfs, int8_t level_type,
             info->fs_name->flags = TSK_FS_NAME_FLAG_ALLOC;
 
             // Make sure there is enough space in cur_key for the name 
-            // (name is unicode so each characters is two bytes; 6 bytes of non-name characters)
-            if ((uint32_t)(tsk_getu16(hfs->fs_info.endian, cur_key->name.length)) * 2 > tsk_getu16(hfs->fs_info.endian, cur_key->key_len) - 6) {
+            // (name is unicode so each characters is two bytes; 6 bytes
+            // of non-name characters)
+            const int32_t nameLength =
+                tsk_getu16(hfs->fs_info.endian, cur_key->name.length);
+            if (2*nameLength > tsk_getu16(hfs->fs_info.endian, cur_key->key_len) - 6) {
                 error_returned
                 ("hfs_dir_open_meta_cb: name length is too long");
                 return HFS_BTREE_CB_ERR;
             }
             if (hfs_UTF16toUTF8(fs, (uint8_t *) cur_key->name.unicode,
-                    tsk_getu16(hfs->fs_info.endian, cur_key->name.length),
-                    info->fs_name->name, HFS_MAXNAMLEN + 1,
+                    nameLength, info->fs_name->name, HFS_MAXNAMLEN + 1,
                     HFS_U16U8_FLAG_REPLACE_SLASH)) {
                 return HFS_BTREE_CB_ERR;
             }
