@@ -38,7 +38,7 @@ aff_read(TSK_IMG_INFO * img_info, TSK_OFF_T offset, char *buf, size_t len)
     }
 
     if (aff_info->seek_pos != offset) {
-        if (af_seek(aff_info->af_file, offset, SEEK_SET) != offset) {
+        if (af_seek(aff_info->af_file, offset, SEEK_SET) != (uint64_t)offset) {
             tsk_error_reset();
             // @@@ ADD more specific error messages
             tsk_error_set_errno(TSK_ERR_IMG_SEEK);
@@ -66,7 +66,7 @@ aff_read(TSK_IMG_INFO * img_info, TSK_OFF_T offset, char *buf, size_t len)
         // @@@ We could improve this if there is an AFF call
         // to see if the data exists or not
         if ((af_eof(aff_info->af_file) == 0) &&
-            (offset + len < img_info->size)) {
+            (offset + (TSK_OFF_T)len < img_info->size)) {
             memset(buf, 0, len);
             cnt = len;
         }
